@@ -7,8 +7,7 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef KALARM_KAEVENT_H
-#define KALARM_KAEVENT_H
+#pragma once
 
 #include "kalarmcal_export.h"
 
@@ -1125,7 +1124,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurDaily(int freq, const QBitArray &days, int count, const QDate &end);
+    bool setRecurDaily(int freq, const QBitArray &days, int count, QDate end);
 
     /** Set the recurrence to recur weekly, on the specified weekdays.
      *  @param freq   how many weeks between recurrences.
@@ -1136,7 +1135,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurWeekly(int freq, const QBitArray &days, int count, const QDate &end);
+    bool setRecurWeekly(int freq, const QBitArray &days, int count, QDate end);
 
     /** Set the recurrence to recur monthly, on the specified days within the month.
      *  @param freq   how many months between recurrences.
@@ -1147,7 +1146,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurMonthlyByDate(int freq, const QVector<int> &days, int count, const QDate &end);
+    bool setRecurMonthlyByDate(int freq, const QVector<int> &days, int count, QDate end);
 
     /** Holds days of the week combined with a week number in the month,
      *  used to specify some monthly or annual recurrences. */
@@ -1167,7 +1166,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurMonthlyByPos(int freq, const QVector<MonthPos> &pos, int count, const QDate &end);
+    bool setRecurMonthlyByPos(int freq, const QVector<MonthPos> &pos, int count, QDate end);
 
     /** Set the recurrence to recur annually, on the specified day in each
      *  of the specified months.
@@ -1182,7 +1181,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurAnnualByDate(int freq, const QVector<int> &months, int day, KARecurrence::Feb29Type, int count, const QDate &end);
+    bool setRecurAnnualByDate(int freq, const QVector<int> &months, int day, KARecurrence::Feb29Type, int count, QDate end);
 
     /** Set the recurrence to recur annually, on the specified weekdays in the
      *  specified weeks of the specified months.
@@ -1195,7 +1194,7 @@ public:
      *  @param end   = end date (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurAnnualByPos(int freq, const QVector<MonthPos> &pos, const QVector<int> &months, int count, const QDate &end);
+    bool setRecurAnnualByPos(int freq, const QVector<MonthPos> &pos, const QVector<int> &months, int count, QDate end);
 
     /** Return whether the event recurs.
      *  @see recurType()
@@ -1474,6 +1473,5 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::Flags)
 Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::Comparison)
 Q_DECLARE_METATYPE(KAlarmCal::KAEvent)
 
-#endif // KALARM_KAEVENT_H
 
 // vim: et sw=4:
